@@ -389,6 +389,11 @@ def check_all_types(
                                 message="Source is from conditional step, but pickValue is not used",
                             )
                         )
+                    if is_all_output_method_loop_step(param_to_step, parm_id):
+                        src_dict[parm_id]["type"] = {
+                            "type": "array",
+                            "items": src_dict[parm_id]["type"],
+                        }
             else:
                 parm_id = cast(str, sink[sourceField])
                 if parm_id not in src_dict:
@@ -430,6 +435,12 @@ def check_all_types(
 
                     srcs_of_sink[0]["type"] = src_typ
 
+                if is_all_output_method_loop_step(param_to_step, parm_id):
+                    src_dict[parm_id]["type"] = {
+                        "type": "array",
+                        "items": src_dict[parm_id]["type"],
+                    }
+
             for src in srcs_of_sink:
                 check_result = check_types(src, sink, linkMerge, valueFrom)
                 if check_result == "warning":
@@ -517,3 +528,43 @@ def is_conditional_step(param_to_step: Dict[str, CWLObjectType], parm_id: str) -
         if source_step.get("when") is not None:
             return True
     return False
+
+
+def is_all_output_method_loop_step(
+    param_to_step: Dict[str, CWLObjectType], parm_id: str
+) -> bool:
+    """Check if a step contains a http://commonwl.org/cwltool#Loop requirement with `all` outputMethod."""
+    source_step: Optional[MutableMapping[str, Any]] = param_to_step.get(parm_id)
+    if source_step is not None:
+        for requirement in source_step.get("requirements", []):
+            if (
+                requirement["class"] == "http://commonwl.org/cwltool#Loop"
+                and requirement.get("outputMethod") == "all"
+            ):
+                return True
+    return False
+
+
+def loop_checker(steps: List[MutableMapping[str, Any]]) -> None:
+    """Check http://commonwl.org/cwltool#Loop requirement compatibility with other directives."""
+    exceptions = []
+    for step in steps:
+        requirements = {
+            **{h["class"]: h for h in step.get("hints", [])},
+            **{r["class"]: r for r in step.get("requirements", [])},
+        }
+        if "http://commonwl.org/cwltool#Loop" in requirements:
+            if "when" in step:
+                exceptions.append(
+                    SourceLine(step, "id").makeError(
+                        "The `cwltool:Loop` clause is not compatible with the `when` directive."
+                    )
+                )
+            if "scatter" in step:
+                exceptions.append(
+                    SourceLine(step, "id").makeError(
+                        "The `cwltool:Loop` clause is not compatible with the `scatter` directive."
+                    )
+                )
+    if exceptions:
+        raise ValidationException("\n".join(exceptions))
