@@ -7,6 +7,10 @@ from typing import Optional
 
 import pytest
 
+from cwltool.context import LoadingContext
+from cwltool.load_tool import load_tool
+from cwltool.software_requirements import get_container_from_software_requirements
+
 from .util import get_data, get_main_output, get_tool_env, needs_docker
 
 deps = None  # type: Optional[ModuleType]
@@ -28,6 +32,17 @@ def test_biocontainers(tmp_path: Path) -> None:
     assert error_code == 0
 
 
+@needs_docker
+@pytest.mark.skipif(not deps, reason="galaxy-tool-util is not installed")
+def test_biocontainers_resolution(tmp_path: Path) -> None:
+    """Confirm expected container name for --beta-use-biocontainers."""
+    tool = load_tool(get_data("tests/seqtk_seq.cwl"), LoadingContext())
+    assert (
+        get_container_from_software_requirements(True, tool)
+        == "quay.io/biocontainers/seqtk:r93--0"
+    )
+
+
 @pytest.mark.skipif(not deps, reason="galaxy-tool-util is not installed")
 def test_bioconda(tmp_path: Path) -> None:
     wflow = get_data("tests/seqtk_seq.cwl")
